@@ -5,17 +5,14 @@ class SparkPostException(Exception):
 class SparkPostAPIException(SparkPostException):
     "Handle 4xx and 5xx errors from the SparkPost API"
     def __init__(self, response, *args, **kwargs):
-        errors = None
         try:
             errors = response.json()['errors']
-            errors = [e['message'] +
-                      ' Code: ' + e.get('code', '') +
-                      ' Description: ' + e.get('description', '') +
-                      '\n'
+            error_template = "{message} Code: {code} Description: {desc} \n"
+            errors = [error_template.format(message=e.get('message', ''),
+                                            code=e.get('code', 'none'),
+                                            desc=e.get('description', 'none'))
                       for e in errors]
         except:
-            pass
-        if not errors:
             errors = [response.text or ""]
         self.status = response.status_code
         self.response = response
