@@ -2,14 +2,16 @@ import base64
 import json
 import os
 import tempfile
+import warnings
 
 import pytest
 import responses
 import six
+from mock import patch
 
 from sparkpost import SparkPost
 from sparkpost import Transmissions
-from sparkpost.exceptions import SparkPostAPIException
+from sparkpost.exceptions import SparkPostAPIException, SparkPostException
 
 
 def test_translate_keys_with_list():
@@ -29,6 +31,12 @@ def test_translate_keys_with_recips():
                                      {'address': {'email': 'foobar'}}]
 
 
+def test_exceptions_for_recipients():
+    t = Transmissions('uri', 'key')
+    with pytest.raises(SparkPostException):
+        t._translate_keys(recipients='test')
+
+
 def test_translate_keys_with_unicode_recips():
     t = Transmissions('uri', 'key')
     results = t._translate_keys(recipients=[u'unicode_email@example.com',
@@ -297,7 +305,8 @@ def test_fail_get():
 
 
 @responses.activate
-def test_success_list():
+@patch.object(warnings, 'warn')
+def test_success_list(mock_warn):
     responses.add(
         responses.GET,
         'https://api.sparkpost.com/api/v1/transmissions',
@@ -307,6 +316,23 @@ def test_success_list():
     )
     sp = SparkPost('fake-key')
     response = sp.transmission.list()
+    assert mock_warn.called
+    assert response == []
+
+
+@responses.activate
+def test_success_list_with_params():
+    responses.add(
+        responses.GET,
+        'https://api.sparkpost.com/api/v1/transmissions?template_id=abcd',
+        status=200,
+        content_type='application/json',
+        body='{"results": []}',
+        match_querystring=True
+
+    )
+    sp = SparkPost('fake-key')
+    response = sp.transmission.list(template_id='abcd')
     assert response == []
 
 
